<?php

namespace Drupal\alt_text_validation;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Interface for Text Rule Configuration entities.
 *
 * Provides an interface defining a text rule entity type.
 */
interface AltTextRuleInterface extends ConfigEntityInterface {

  /**
   * Sets the Text Rule type.
   *
   * @param string $rule_type
   *   The Text Rule type.
   *
   * @return $this
   *   The called Text Rule entity.
   */
  public function setRuleType(string $rule_type): AltTextRuleInterface;

  /**
   * Gets the Text Rule type.
   *
   * @return ?string
   *   The Text Rule type or NULL.
   */
  public function getRuleType(): ?string;

  /**
   * Sets the content character limit.
   *
   * @param int $content_char_limit
   *   The content character limit.
   *
   * @return $this
   *   The called Text Rule entity.
   */
  public function setContentCharLimit(int $content_char_limit): AltTextRuleInterface;

  /**
   * Gets the content character limit, or NULL if uninitialized.
   *
   * @return ?int
   *   The content character limit or NULL.
   */
  public function getContentCharLimit(): ?int;

  /**
   * Sets the text to compare.
   *
   * @param string $text_to_compare
   *   The text to compare.
   *
   * @return $this
   *   The called Text Rule entity.
   */
  public function setTextToCompare(string $text_to_compare): AltTextRuleInterface;

  /**
   * Gets the text to compare, or NULL if uninitialized.
   *
   * @return ?string
   *   The text to compare or NULL.
   */
  public function getTextToCompare(): ?string;

  /**
   * Sets the violation action.
   *
   * @param string $violation_action
   *   The violation action.
   *
   * @return $this
   *   The called Text Rule entity.
   */
  public function setViolationAction(string $violation_action): AltTextRuleInterface;

  /**
   * Gets the violation action, or NULL if uninitialized.
   *
   * @return ?string
   *   The violation action.
   */
  public function getViolationAction(): ?string;

  /**
   * Sets the violation message.
   *
   * @param string $violation_message
   *   The violation message.
   *
   * @return $this
   *   The called Text Rule entity.
   */
  public function setViolationMessage(string $violation_message): AltTextRuleInterface;

  /**
   * Gets the violation message.
   *
   * @return string
   *   The violation message.
   */
  public function getViolationMessage(): ?string;

}
