<?php

namespace Drupal\alt_text_validation\Entity;

use Drupal\alt_text_validation\AltTextRuleInterface;
use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the AltTextRule entity.
 *
 * @ConfigEntityType(
 *   id = "alt_text_rule",
 *   label = @Translation("Alt-Text Rule"),
 *   module = "alt_text_validation",
 *   handlers = {
 *     "list_builder" = "Drupal\alt_text_validation\AltTextRuleListBuilder",
 *      "form" = {
 *        "add" = "Drupal\alt_text_validation\Form\AltTextRuleForm",
 *        "edit" = "Drupal\alt_text_validation\Form\AltTextRuleForm",
 *        "default" = "Drupal\alt_text_validation\Form\AltTextRuleForm",
 *        "delete" = "Drupal\alt_text_validation\Form\AltTextRuleDeleteForm"
 *      },
 *      "route_provider" = {
 *        "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *      }
 *   },
 *   config_prefix = "alt_text_rule",
 *   admin_permission = "administer alt text validation",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "rule_type" = "rule_type",
 *   },
 *   links = {
 *     "canonical" = "/admin/config/content/alt-text-validation/alt-text-rule/{alt_text_rule}",
 *     "add-form" = "/admin/config/content/alt-text-validation/alt-text-rule/add",
 *     "edit-form" = "/admin/config/content/alt-text-validation/alt-text-rule/{alt_text_rule}/edit",
 *     "delete-form" = "/admin/config/content/alt-text-validation/alt-text-rule/{alt_text_rule}/delete",
 *     "collection" = "/admin/config/content/alt-text-validation/alt-text-rule"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "rule_type",
 *     "content_char_limit",
 *     "text_to_compare",
 *     "violation_action",
 *     "violation_message",
 *   }
 * )
 */
class AltTextRule extends ConfigEntityBase implements AltTextRuleInterface {

  /**
   * The Text Rule ID.
   *
   * @var string
   */
  protected string $id;

  /**
   * The Text Rule Label.
   *
   * @var string
   */
  protected string $label;

  /**
   * The rule type.
   *
   * @var string
   */
  protected $rule_type;

  /**
   * The content character limit.
   *
   * @var int
   */
  protected $content_char_limit;

  /**
   * The text to compare against.
   *
   * @var string
   */
  protected string $text_to_compare;

  /**
   * The action to take on violation.
   *
   * @var string
   */
  protected string $violation_action;

  /**
   * The message to display when an violation occurs.
   *
   * @var string
   */
  protected string $violation_message;

  /**
   * {@inheritdoc}
   */
  public function setRuleType(string $rule_type): AltTextRuleInterface {
    $this->rule_type = $rule_type;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getRuleType(): ?string {
    return $this->rule_type;
  }

  /**
   * {@inheritdoc}
   */
  public function setContentCharLimit(int $content_char_limit): AltTextRuleInterface {
    $this->content_char_limit = $content_char_limit;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getContentCharLimit(): ?int {
    return $this->content_char_limit;
  }

  /**
   * {@inheritdoc}
   */
  public function setTextToCompare(string $text_to_compare): AltTextRuleInterface {
    $this->text_to_compare = $text_to_compare;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getTextToCompare(): ?string {
    return $this->text_to_compare;
  }

  /**
   * {@inheritdoc}
   */
  public function setViolationAction(string $violation_action): AltTextRuleInterface {
    $this->violation_action = $violation_action;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getViolationAction(): ?string {
    return $this->violation_action;
  }

  /**
   * {@inheritdoc}
   */
  public function setViolationMessage(string $violation_message): AltTextRuleInterface {
    $this->violation_message = $violation_message;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getViolationMessage(): ?string {
    return $this->violation_message;
  }

}
